require File.dirname(__FILE__) + "/helpers.rb"

require "sensu/utilities"

describe "Sensu::Utilities" do
  include Helpers
  include Sensu::Utilities

  it "can determine that we are testing" do
    expect(testing?).to be(true)
  end

  it "can deep merge two hashes" do
    hash_one = {
      :foo => 1,
      :bar => {
        :one => 1,
        :two => {
          :three => 3
        }
      },
      :baz => ["one"],
      :qux => 42
    }
    hash_two = {
      :foo => 42,
      :bar => {
        :one => "one",
        :two => {
          :three => 3,
          :four => 4
        }
      },
      :baz => ["one", "two", "three"],
      :qux => [42]
    }
    expected = {
      :foo => 42,
      :bar => {
        :one => "one",
        :two => {
          :three => 3,
          :four => 4
        }
      },
      :baz => ["one", "two", "three"],
      :qux => [42]
    }
    expect(deep_merge(hash_one, hash_two)).to eq(expected)
  end

  it "can generate a random uuid" do
    uuid = random_uuid
    expect(uuid).to be_kind_of(String)
    expect(uuid.size).to eq(36)
    expect(uuid).not_to eq(random_uuid)
  end

  it "can redact sensitive info from a hash" do
    hash = {
      :one => 1,
      :password => "foo",
      :nested => {
        :password => "bar"
      },
      :diff_one => [nil, {:secret => "baz"}],
      :diff_two => [{:secret => "baz"}, {:secret => "qux"}]
    }
    redacted = redact_sensitive(hash)
    expect(redacted[:one]).to eq(1)
    expect(redacted[:password]).to eq("REDACTED")
    expect(redacted[:nested][:password]).to eq("REDACTED")
    expect(redacted[:diff_one][1][:secret]).to eq("REDACTED")
    expect(redacted[:diff_two][0][:secret]).to eq("REDACTED")
    expect(redacted[:diff_two][1][:secret]).to eq("REDACTED")
  end

  it "can substitute dot notation tokens" do
    string = ":::nested.attribute|default::: :::missing|default:::"
    string << " :::missing|::: :::missing::: :::nested.attribute:::::::nested.attribute:::"
    string << " :::empty|localhost::: :::empty.hash|localhost:8080:::"
    attributes = {
      :nested => {
        :attribute => true
      },
      :empty => {}
    }
    result, unmatched_tokens = substitute_tokens(string, attributes)
    expect(result).to eq("true default   true:true localhost localhost:8080")
    expect(unmatched_tokens).to eq(["missing"])
  end
end
